@@ -43,8 +43,8 @@ main(int argc, char **argv)
             0,
             64,
             IPPROTO_UDP,
-            name_resolve(IP1),
-            name_resolve(IP2),
+            name_resolve(IP1, 1),
+            name_resolve(IP2 ,1),
             NULL,
             buf);
 
